betty.locale.translation module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.locale.translation module

Manage translations of built-in translatable strings.

async betty.locale.translation.init_translation(locale: str) → None

  Initialize a new translation.

async betty.locale.translation.update_translations(_output_assets_directory_path: Path = PosixPath('/home/runner/work/betty/betty/betty/assets')) → None

  Update all existing translations based on changes in translatable strings.